==> dhall-bash-1.0.40-260-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-bash
version:              1.0.40
visibility:           public
id:                   dhall-bash-1.0.40-1i21diSqUF87smmzXxXWuX
key:                  dhall-bash-1.0.40-1i21diSqUF87smmzXxXWuX
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  0e4f72a136655fb5419a12348f210b09
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.40-1i21diSqUF87smmzXxXWuX
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dhall-1.41.2-6pWXjagA63zFX71j1T9v5E
    neat-interpolation-0.5.1.4-4e6SZe5pYCgASw1E2Q4q5G
    shell-escape-0.2.0-G3UlFOV3zwoDBjYDT4yLAO text-1.2.5.0

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-bash-1.0.40-262-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-bash
version:              1.0.40
visibility:           public
id:                   dhall-bash-1.0.40-CQDAQwgO5ci7EOdgPWg2tp
key:                  dhall-bash-1.0.40-CQDAQwgO5ci7EOdgPWg2tp
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  6738f59eaeddcf965b48ccd063d08e75
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.40-CQDAQwgO5ci7EOdgPWg2tp
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dhall-1.41.2-9dESknbvtGWIHcbSnxdnNe
    neat-interpolation-0.5.1.4-5T1tzunA1kdIX31bn1DUFI
    shell-escape-0.2.0-G3UlFOV3zwoDBjYDT4yLAO text-1.2.5.0

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
